==> scilab_5.3.3.orig.tar.gz: scilab-5.3.3/modules/xcos/sci_gateway/cpp/sci_xcosPalGenerateIcon.cpp <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) DIGITEO - 2010-2010 - Clément DAVID <clement.david@scilab.org>
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

#include "Palette.hxx"
#include "GiwsException.hxx"
#include "xcosUtilities.hxx"

extern "C"
{
#include "gw_xcos.h"
#include "stack-c.h"
#include "callxcos.h"
#include "api_scilab.h"
#include "localization.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "getScilabJavaVM.h"
}

using namespace org_scilab_modules_xcos_palette;

int
sci_xcosPalGenerateIcon(char *fname, unsigned long fname_len)
{
    CheckRhs(2, 2);
    CheckLhs(0, 1);

    char* blockPath = NULL;
    char* iconPath = NULL;

    /* blockPath setup */
    if(readSingleString(pvApiCtx, 1, &blockPath, fname))
    {
        return 0;
    }

    /* iconPath setup */
    if(readSingleString(pvApiCtx, 2, &iconPath, fname))
    {
        FREE(blockPath);
        return 0;
    }

    /* Call the java implementation */
    try
    {
        Palette::generatePaletteIcon(getScilabJavaVM(), blockPath, iconPath);
    }
    catch (GiwsException::JniCallMethodException exception)
    {
        Scierror(999, "%s: %s\n", fname, exception.getJavaDescription().c_str());
        return 0;
    }
    catch (GiwsException::JniException exception)
    {
        Scierror(999, "%s: %s\n", fname, exception.what());
        return 0;
    }

    PutLhsVar();
    return 0;
}

==> scilab_5.4.0.0.orig.tar.gz: scilab-5.4.0/modules/xcos/sci_gateway/cpp/sci_xcosPalGenerateIcon.cpp <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) DIGITEO - 2010-2010 - Clément DAVID <clement.david@scilab.org>
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */

#include "Palette.hxx"
#include "GiwsException.hxx"
#include "xcosUtilities.hxx"

extern "C"
{
#include "gw_xcos.h"
#include "api_scilab.h"
#include "localization.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "getScilabJavaVM.h"
}

using namespace org_scilab_modules_xcos_palette;

int sci_xcosPalGenerateIcon(char *fname, unsigned long fname_len)
{
    CheckRhs(2, 2);
    CheckLhs(0, 1);

    char *blockName = NULL;
    char *iconPath = NULL;

    /* blockName setup */
    if (readSingleString(pvApiCtx, 1, &blockName, fname))
    {
        return 0;
    }

    /* iconPath setup */
    if (readSingleString(pvApiCtx, 2, &iconPath, fname))
    {
        FREE(blockName);
        return 0;
    }

    /* Call the java implementation */
    try
    {
        Palette::generatePaletteIcon(getScilabJavaVM(), blockName, iconPath);
    }
    catch (GiwsException::JniCallMethodException &exception)
    {
        Scierror(999, "%s: %s\n", fname, exception.getJavaDescription().c_str());
    }
    catch (GiwsException::JniException &exception)
    {
        Scierror(999, "%s: %s\n", fname, exception.whatStr().c_str());
    }


    FREE(blockName);
    FREE(iconPath);

    PutLhsVar();
    return 0;
}
